@@ -92,7 +92,7 @@ class Simulation(object):
 
     # pylint: disable=too-many-locals
     def launch(self, experiment_id, experiment_conf, server, reservation, cloned=True,
-               storage_token=None):
+               storage_token=None, brain_processes=1, profiler='disabled'):
         """
         Attempt to launch and initialize the given experiment on the given servers. This
         should not be directly invoked by users, use the VirtualCoach interface to validate
@@ -105,6 +105,8 @@ class Simulation(object):
         :param reservation: A string representing a cluster resource reservation (if any).
         :param cloned: Boolean. True if the experiment is cloned.
         :param storage_token: A string representing the token for storage authorization.
+        :param brain_processes: Number of mpi processes in the brain simulation.
+        :param profiler: profiler option. Possible values are: disabled, cle_step and cprofile.
         """
         assert isinstance(experiment_id, string_types)
         assert isinstance(experiment_conf, string_types)
@@ -135,7 +137,8 @@ class Simulation(object):
             url = '%s/%s' % (self.__server_info['gzweb']['nrp-services'],
                              self.__config['simulation-services']['create'])
             sim_info = {'experimentID': experiment_id,
-                        'brainProcesses': 1,
+                        'brainProcesses': brain_processes,
+                        'profiler': profiler,
                         'experimentConfiguration': experiment_conf,
                         'gzserverHost': self.__server_info['serverJobLocation'],
                         'reservation': reservation,
@@ -715,6 +718,7 @@ class Simulation(object):
         # check for current simulation state and pause simulation if it's running
         if self.get_state() == 'started':
             started = True
+            self.pause()
         try:
             status_code, _ = self.__http_client.put(url, body=body)
             if status_code != http.client.OK:
