@@ -249,7 +249,8 @@ class VirtualCoach(object):
 
         return token
 
-    def launch_experiment(self, experiment_id, server=None, reservation=None, cloned=True):
+    def launch_experiment(self, experiment_id, server=None, reservation=None, cloned=True, brain_processes=1,
+                          profiler='disabled'):
         """
         Attempts to launch a simulation with the given parameters. If no server is explicitly given
         then all available backend servers will be tried. Only cloned experiments to the Storage
@@ -263,6 +264,8 @@ class VirtualCoach(object):
                             specific resources, otherwise use any available resources.
         :param cloned: (optional) True or False depending on if the launched
                        is a cloned experiment or not.
+        :param brain_processes: (optional) Number of mpi processes in the brain simulation.
+        :param profiler: (optional) profiler option. Possible values are: disabled, cle_step and cprofile.
         """
         assert isinstance(experiment_id, string_types)
         assert isinstance(server, (string_types, type(None)))
@@ -304,7 +307,7 @@ class VirtualCoach(object):
         for server_i in servers:
             try:
                 if sim.launch(experiment_id, str(experiment_conf), str(server_i),
-                              reservation, cloned, self.__storage_token):
+                              reservation, cloned, self.__storage_token, brain_processes, profiler):
                     return sim
 
             # pylint: disable=broad-except
